@@ -1,4 +1,4 @@
-from . import contest, __version__
+from . import contest, problem, account, __version__
 from argparse import ArgumentParser, ArgumentDefaultsHelpFormatter
 
 def main():
@@ -9,6 +9,7 @@ def main():
 
     _list = subparsers.add_parser('list', aliases=['l'], help="List contests", allow_abbrev=True)
     _list.add_argument('-f', '--force',  action='store_true', help="Update cache")
+    _list.add_argument('-s', '--solved',  action='store_true', help="Update solved problems")
     _list.add_argument('-a', '--all',  action='store_true', help="Show all contests")
     _list.set_defaults(func=contest.list_past_contest)
 
@@ -18,16 +19,16 @@ def main():
 
     _solution = subparsers.add_parser('solution', aliases=['q'], help="Get problem's solutions", allow_abbrev=True)
     _solution.add_argument('cid', metavar='contestID', nargs='?', action='store', type=int)
-    _solution.add_argument('level', metavar='contestID', nargs='?', action='store', type=str)
+    _solution.add_argument('level', metavar='problem level', nargs='?', action='store', type=str)
     _solution.set_defaults(func=contest.get_solutions)
 
     _info = subparsers.add_parser('info', aliases=['i'], help="Show contest info")
     _info.add_argument('cid', metavar='contestID', nargs='?', action='store', type=int)
-    _info.add_argument('level', metavar='contestID', nargs='?', action='store', type=str)
+    _info.add_argument('level', metavar='problem level', nargs='?', action='store', type=str)
     _info.set_defaults(func=contest.show_contest_info)
 
     _login = subparsers.add_parser('login', help="Sign in codeforces account")
-    _login.set_defaults(func=contest.login)
+    _login.set_defaults(func=account.login)
 
     _editorial = subparsers.add_parser('editorial', aliases=['d'], help="Search editorial links")
     _editorial.add_argument('cid', metavar='contestID', nargs='?', action='store', type=int)
@@ -35,9 +36,15 @@ def main():
 
     _open = subparsers.add_parser('open', aliases=['o'], help="Open codeforces URL")
     _open.add_argument('cid', metavar='contestID', nargs='?', action='store', type=int)
-    _open.add_argument('level', metavar='contestID', nargs='?', action='store', type=str)
+    _open.add_argument('level', metavar='problem level', nargs='?', action='store', type=str)
     _open.set_defaults(func=contest.open_url)
 
+    _submit = subparsers.add_parser('submit', aliases=['s'], help="Submit a solution file")
+    _submit.add_argument('cid', metavar='contestID', nargs='?', action='store', type=int)
+    _submit.add_argument('level', metavar='level', nargs='?', action='store', type=str)
+    _submit.add_argument('-i', '--input', action='store', type=str, help="Input source")
+    _submit.set_defaults(func=problem.submit)
+
     args = parser.parse_args()
     if 'func' in args:
         args.func(args)
